==================
LCP video analysis
==================

.. image:: https://img.shields.io/travis/vstadnytskyi/lcp-video.svg
        :target: https://travis-ci.org/vstadnytskyi/lcp-video

.. image:: https://img.shields.io/pypi/v/lcp-video.svg
        :target: https://pypi.python.org/pypi/lcp-video


LCP video analysis

* Free software: 3-clause BSD license
* Documentation: (COMING SOON!) https://vstadnytskyi.github.io/lcp-video.

Features
--------

* TODO
